@@ -7,7 +7,7 @@
 /*  commands.                                                  */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2023 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2024 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -199,9 +199,11 @@ int DoRem(ParsePtr p)
     } else {
         /* Parse the rest of the line to catch any potential
            expression-pasting errors */
-        while (ParseChar(p, &r, 0)) {
-            if (r != 0) {
-                break;
+        if (ParseUntriggered) {
+            while (ParseChar(p, &r, 0)) {
+                if (r != 0) {
+                    break;
+                }
             }
         }
     }
@@ -348,6 +350,16 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals)
 	    if (r) return r;
 	    break;
 
+        /* A time implicitly introduces an AT if AT is not explicit */
+        case T_Time:
+            DBufFree(&buf);
+            if (tim->ttime != NO_TIME) return E_TIME_TWICE;
+            tim->ttime = tok.val;
+            r = ParseTimeTrig(s, tim, save_in_globals);
+            if (r) return r;
+	    trig->duration_days = ComputeTrigDuration(tim);
+	    break;
+
 	case T_At:
 	    DBufFree(&buf);
 	    r=ParseTimeTrig(s, tim, save_in_globals);
@@ -1134,7 +1146,12 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse, int is_queue
 	if (msg_command) {
 	    DoMsgCommand(msg_command, DBufValue(&buf));
 	} else {
-	    printf("%s", DBufValue(&buf));
+            /* Add a space before "NOTE endreminder" */
+            if (IsServerMode() && !strncmp(DBufValue(&buf), "NOTE endreminder", 16)) {
+                printf(" %s", DBufValue(&buf));
+            } else {
+                printf("%s", DBufValue(&buf));
+            }
 	}
 	break;
 
@@ -1182,7 +1199,7 @@ int ShouldTriggerReminder(Trigger *t, TimeTrig *tim, int dse, int *err)
 	if (DontIssueAts > 1) {
 	    /* If two or more -a options, then *DO* issue ats that are in the
 	       future */
-	    if (tim->ttime < SystemTime(0) / 60) {
+	    if (tim->ttime < MinutesPastMidnight(0)) {
 		return 0;
 	    }
 	} else {
@@ -1190,29 +1207,31 @@ int ShouldTriggerReminder(Trigger *t, TimeTrig *tim, int dse, int *err)
 	}
     }
 
-    /* Don't trigger "old" timed reminders */
-/*** REMOVED...
-  if (dse == DSEToday &&
-  tim->ttime != NO_TIME &&
-  tim->ttime < SystemTime(0) / 60) return 0;
-  *** ...UNTIL HERE */
-
     /* If "infinite delta" option is chosen, always trigger future reminders */
     if (InfiniteDelta || NextMode) return 1;
 
-    /* If there's a "warn" function, it overrides any deltas */
+    /* If there's a "warn" function, it overrides any deltas except
+     * DeltaOverride*/
     if (t->warn[0] != 0) {
-	if (DeltaOffset) {
-	    if (dse <= DSEToday + DeltaOffset) {
+	if (DeltaOverride > 0) {
+	    if (dse <= DSEToday + DeltaOverride) {
 		return 1;
 	    }
 	}
 	return ShouldTriggerBasedOnWarn(t, dse, err);
     }
 
+    /* Zero delta */
+    if (DeltaOverride < 0) {
+        return dse == DSEToday;
+    }
+
     /* Move back by delta days, if any */
-    if (t->delta != NO_DELTA) {
-	if (t->delta < 0)
+    if (DeltaOverride) {
+        /* A positive DeltaOverride takes precedence over everything */
+        dse = dse - DeltaOverride;
+    } else if (t->delta != NO_DELTA) {
+        if (t->delta < 0)
 	    dse = dse + t->delta;
 	else {
 	    int iter = 0;
@@ -1237,7 +1256,7 @@ int ShouldTriggerReminder(Trigger *t, TimeTrig *tim, int dse, int *err)
     }
 
     /* Should we trigger the reminder? */
-    return (dse <= DSEToday + DeltaOffset);
+    return (dse <= DSEToday);
 }
 
 /***************************************************************/
