@@ -50,6 +50,7 @@ EXTERN  int	LineNo;
 EXTERN  int     FreshLine;
 EXTERN  uid_t   TrustedUsers[MAX_TRUSTED_USERS];
 
+EXTERN  INIT(   int     MaxLateMinutes, 0);
 EXTERN  INIT(   int     NumTrustedUsers, 0);
 EXTERN  INIT(   char    const *MsgCommand, NULL);
 EXTERN  INIT(   char    const *QueuedMsgCommand, NULL);
@@ -70,7 +71,7 @@ EXTERN  INIT(	int 	Hush, 0);
 EXTERN  INIT(	int 	NextMode, 0);
 EXTERN  INIT(	int 	InfiniteDelta, 0);
 EXTERN  INIT(   int     DefaultTDelta, 0);
-EXTERN  INIT(   int     DeltaOffset, 0);
+EXTERN  INIT(   int     DeltaOverride, 0);
 EXTERN  INIT(   int     RunDisabled, 0);
 EXTERN  INIT(   int     IgnoreOnce, 0);
 EXTERN  INIT(   int     SortByTime, 0);
@@ -78,7 +79,8 @@ EXTERN  INIT(   int     SortByDate, 0);
 EXTERN	INIT(	int	SortByPrio, 0);
 EXTERN  INIT(   int     UntimedBeforeTimed, 0);
 EXTERN	INIT(	int	DefaultPrio, NO_PRIORITY);
-EXTERN  INIT(   long    SysTime, -1L);
+EXTERN  INIT(   int     SysTime, -1);
+EXTERN  INIT(   int     ParseUntriggered, 1);
 
 EXTERN	char	const *InitialFile;
 EXTERN	int	FileAccessDate;
@@ -100,7 +102,7 @@ EXTERN  INIT(   int     SynthesizeTags, 0);
 EXTERN  INIT(   int     ScFormat, SC_AMPM);
 EXTERN  INIT(   int     MaxSatIter, 1000);
 EXTERN  INIT(   int     MaxStringLen, MAX_STR_LEN);
-EXTERN  INIT(	char	*FileName, NULL);
+EXTERN  INIT(	char    *FileName, NULL);
 EXTERN	INIT(	int	UseStdin, 0);
 EXTERN  INIT(   int     PurgeMode, 0);
 EXTERN  INIT(   int     PurgeIncludeDepth, 0);
@@ -155,6 +157,9 @@ EXTERN	INIT(	char	  *EndSentIg, "\"')]}>");
 EXTERN DynamicBuffer Banner;
 EXTERN DynamicBuffer LineBuffer;
 EXTERN DynamicBuffer ExprBuf;
+
+extern int NumFullOmits, NumPartialOmits;
+
 /* List of months */
 EXTERN  char    *EnglishMonthName[]
 #ifdef MK_GLOBALS
