@@ -7,7 +7,7 @@
 /*  in normal mode.                                            */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2023 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2024 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -25,10 +25,11 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
-
+#include <poll.h>
 #include <pwd.h>
 #include <unistd.h>
 #include <sys/ioctl.h>
+#include <termios.h>
 
 #ifdef HAVE_INITGROUPS
 #include <grp.h>
@@ -40,6 +41,14 @@
 #include "expr.h"
 #include "err.h"
 
+static int should_guess_terminal_background = 1;
+
+static void guess_terminal_background(int *r, int *g, int *b);
+static int tty_init(int fd);
+static void tty_raw(int fd);
+static void tty_reset(int fd);
+
+static void ProcessLongOption(char const *arg);
 /***************************************************************
  *
  *  Command line options recognized:
@@ -219,7 +228,7 @@ void InitRemind(int argc, char const *argv[])
 	}
     } else {
         fprintf(stderr, "Invoked with a NULL argv[0]; bailing because that's just plain bizarre.\n");
-        exit(1);
+        exit(EXIT_FAILURE);
     }
 
     /* Parse the command-line options */
@@ -243,6 +252,11 @@ void InitRemind(int argc, char const *argv[])
                 while(*arg) arg++;
                 break;
 
+            case '-':
+                ProcessLongOption(arg);
+                while(*arg) arg++;
+                break;
+
 	    case '@':
 		UseVTColors = 1;
 		if (*arg) {
@@ -259,16 +273,24 @@ void InitRemind(int argc, char const *argv[])
 		if (*arg == ',') {
 		    arg++;
                     if (*arg != ',') {
-                        PARSENUM(x, arg);
-                        if (x == 0) {
-                            TerminalBackground = TERMINAL_BACKGROUND_DARK;
-                        } else if (x == 1) {
-                            TerminalBackground = TERMINAL_BACKGROUND_LIGHT;
-                        } else if (x == 2) {
-                            TerminalBackground = TERMINAL_BACKGROUND_UNKNOWN;
+                        if (*arg == 't') {
+                            arg++;
+                            should_guess_terminal_background = 2;
                         } else {
-                            fprintf(ErrFp, "%s: -@n,m,b: m must be 0, 1 or 2 (assuming 2)\n",
-                                    argv[0]);
+                            PARSENUM(x, arg);
+                            if (x == 0) {
+                                should_guess_terminal_background = 0;
+                                TerminalBackground = TERMINAL_BACKGROUND_DARK;
+                            } else if (x == 1) {
+                                should_guess_terminal_background = 0;
+                                TerminalBackground = TERMINAL_BACKGROUND_LIGHT;
+                            } else if (x == 2) {
+                                should_guess_terminal_background = 0;
+                                TerminalBackground = TERMINAL_BACKGROUND_UNKNOWN;
+                            } else {
+                                fprintf(ErrFp, "%s: -@n,m,b: m must be t, 0, 1 or 2 (assuming 2)\n",
+                                        argv[0]);
+                            }
                         }
                     }
 		}
@@ -341,10 +363,15 @@ void InitRemind(int argc, char const *argv[])
                 } else if (!*arg) {
 		    InfiniteDelta = 1;
 		} else {
-		    PARSENUM(DeltaOffset, arg);
-		    if (DeltaOffset < 0) {
-			DeltaOffset = 0;
-		    }
+                    if (*arg == 'z') {
+                        DeltaOverride = -1;
+                        arg++;
+                    } else {
+                        PARSENUM(DeltaOverride, arg);
+                        if (DeltaOverride < 0) {
+                            DeltaOverride = 0;
+                        }
+                    }
 		}
 		break;
 	    case 'e':
@@ -532,7 +559,7 @@ void InitRemind(int argc, char const *argv[])
                         arg++;
                         /* -wt means get width from /dev/tty */
                         ttyfd = open("/dev/tty", O_RDONLY);
-                        if (!ttyfd) {
+                        if (ttyfd < 0) {
                             fprintf(stderr, "%s: `-wt': Cannot open /dev/tty: %s\n",
                                     argv[0], strerror(errno));
                         } else {
@@ -543,7 +570,12 @@ void InitRemind(int argc, char const *argv[])
                         PARSENUM(CalWidth, arg);
                         if (CalWidth != 0 && CalWidth < 71) CalWidth = 71;
                         if (CalWidth == 0) {
-                            CalWidth = -1;
+                            /* Cal width of 0 means obtain from stdout */
+                            if (isatty(STDOUT_FILENO)) {
+                                InitCalWidthAndFormWidth(STDOUT_FILENO);
+                            } else {
+                                CalWidth = 80;
+                            }
                         }
                         FormWidth = CalWidth - 8;
                         if (FormWidth < 20) FormWidth = 20;
@@ -721,7 +753,7 @@ void InitRemind(int argc, char const *argv[])
 
 /* Figure out the offset from UTC */
     if (CalculateUTC)
-	(void) CalcMinsFromUTC(DSEToday, SystemTime(0)/60,
+	(void) CalcMinsFromUTC(DSEToday, MinutesPastMidnight(0),
 			       &MinsFromUTC, NULL);
 }
 
@@ -735,7 +767,7 @@ void InitRemind(int argc, char const *argv[])
 #ifndef L_USAGE_OVERRIDE
 void Usage(void)
 {
-    fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-2023 Dianne Skoll\n", VERSION, L_LANGNAME);
+    fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-2024 Dianne Skoll\n", VERSION, L_LANGNAME);
 #ifdef BETA
     fprintf(ErrFp, ">>>> BETA VERSION <<<<\n");
 #endif
@@ -953,3 +985,139 @@ AddTrustedUser(char const *username)
     NumTrustedUsers++;
 }
 
+static void
+ProcessLongOption(char const *arg)
+{
+    if (!strcmp(arg, "version")) {
+        printf("%s\n", VERSION);
+        exit(EXIT_SUCCESS);
+    }
+    fprintf(ErrFp, "%s: Unknown long option --%s\n", ArgV[0], arg);
+}
+
+static void
+guess_terminal_background(int *r, int *g, int *b)
+{
+    int ttyfd;
+    struct pollfd p;
+    int rr, gg, bb;
+    char buf[128];
+    int n;
+
+    *r = -1;
+    *g = -1;
+    *b = -1;
+
+    /* Don't guess if stdout not a terminal unless asked to by @,t */
+    if (should_guess_terminal_background != 2) {
+        if (!isatty(STDOUT_FILENO)) {
+            return;
+        }
+    }
+
+    ttyfd = open("/dev/tty", O_RDWR);
+    if (ttyfd < 0) {
+        return;
+    }
+
+    if (!isatty(ttyfd)) {
+        /* Not a TTY: Can't guess the color */
+        close(ttyfd);
+        return;
+    }
+
+    if (!tty_init(ttyfd)) {
+        return;
+    }
+    tty_raw(ttyfd);
+    n = write(ttyfd, "\033]11;?\033\\", 8);
+
+    if (n != 8) {
+        /* write failed... WTF?  Not much we can do */
+        return;
+    }
+
+    /* Wait up to 0.1s for terminal to respond */
+    p.fd = ttyfd;
+    p.events = POLLIN;
+    if (poll(&p, 1, 100) < 0) {
+        tty_reset(ttyfd);
+        close(ttyfd);
+        return;
+    }
+    if (!(p.revents & POLLIN)) {
+        tty_reset(ttyfd);
+        close(ttyfd);
+        return;
+    }
+    n = read(ttyfd, buf, 127);
+    if (n <= 0) {
+        tty_reset(ttyfd);
+        close(ttyfd);
+        return;
+    }
+    tty_reset(ttyfd);
+    buf[n+1] = 0;
+    if (n < 25) {
+        /* Too short */
+        return;
+    }
+    if (sscanf(buf+5, "rgb:%x/%x/%x", &rr, &gg, &bb) != 3) {
+        /* Couldn't scan color codes */
+        return;
+    }
+    *r = (rr >> 8) & 255;
+    *g = (gg >> 8) & 255;
+    *b = (bb >> 8) & 255;
+}
+
+static struct termios orig_termios;
+
+static int
+tty_init(int fd)
+{
+    if (tcgetattr(fd, &orig_termios) < 0) {
+        return 0;
+    }
+    return 1;
+}
+
+static void
+tty_raw(int fd)
+{
+    struct termios raw;
+
+    raw = orig_termios;
+
+    raw.c_iflag &= ~(BRKINT | ICRNL | INPCK | ISTRIP | IXON);
+    raw.c_oflag &= ~(OPOST);
+    raw.c_cflag |= (CS8);
+    raw.c_lflag &= ~(ECHO | ICANON | IEXTEN | ISIG);
+
+    /* put terminal in raw mode after flushing */
+    tcsetattr(fd,TCSAFLUSH,&raw);
+}
+
+static void
+tty_reset(int fd)
+{
+    tcsetattr(fd, TCSAFLUSH, &orig_termios);
+}
+
+int
+GetTerminalBackground(void)
+{
+    int r, g, b;
+    if (should_guess_terminal_background) {
+        guess_terminal_background(&r, &g, &b);
+        if (r >= 0 && g >= 0 && b >= 0) {
+            if (r+g+b <= 85*3 && r <= 128 && g <= 128 && b <= 128) {
+                TerminalBackground = TERMINAL_BACKGROUND_DARK;
+            } else {
+                TerminalBackground = TERMINAL_BACKGROUND_LIGHT;
+            }
+        }
+        should_guess_terminal_background = 0;
+    }
+    return TerminalBackground;
+}
