@@ -6,7 +6,7 @@
 /*  routines, etc.                                             */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2023 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2024 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -26,16 +26,10 @@
 #endif
 
 #include <ctype.h>
-#ifdef TIME_WITH_SYS_TIME
-#include <time.h>
+#if defined(HAVE_SYS_TIME_H)
 #include <sys/time.h>
-#else
-#if defined(HAVE_SYS_TIME_H) || defined (TIME_WITH_SYS_TIME)
-#include <sys/time.h>
-#else
+#endif
 #include <time.h>
-#endif
-#endif
 
 #include <sys/types.h>
 #ifdef REM_USE_WCHAR
@@ -187,14 +181,14 @@ static void DoReminders(void)
 
     if (FileAccessDate < 0) {
 	fprintf(ErrFp, "%s: `%s': %s.\n", ErrMsg[E_CANTACCESS], InitialFile, strerror(errno));
-	exit(1);
+	exit(EXIT_FAILURE);
     }
 
     r=IncludeFile(InitialFile);
     if (r) {
 	fprintf(ErrFp, "%s %s: %s\n", ErrMsg[E_ERR_READING],
 		InitialFile, ErrMsg[r]);
-	exit(1);
+	exit(EXIT_FAILURE);
     }
 
     while(1) {
@@ -202,7 +196,7 @@ static void DoReminders(void)
 	if (r == E_EOF) return;
 	if (r) {
 	    Eprint("%s: %s", ErrMsg[E_ERR_READING], ErrMsg[r]);
-	    exit(1);
+	    exit(EXIT_FAILURE);
 	}
 	s = FindInitialToken(&tok, CurLine);
 
@@ -753,19 +747,32 @@ int PushToken(char const *tok, ParsePtr p)
 /*  Return the system time in seconds past midnight            */
 /*                                                             */
 /***************************************************************/
-long SystemTime(int realtime)
+int SystemTime(int realtime)
 {
-    time_t tloc;
+    time_t now;
     struct tm *t;
 
-    if (!realtime && (SysTime != -1L)) return SysTime;
+    if (!realtime && (SysTime != -1)) return SysTime;
 
-    (void) time(&tloc);
-    t = localtime(&tloc);
-    return (long) t->tm_hour * 3600L + (long) t->tm_min * 60L +
-	(long) t->tm_sec;
+    now = time(NULL);
+    t = localtime(&now);
+    return t->tm_hour * 3600L + t->tm_min * 60L +
+	t->tm_sec;
 }
 
+/***************************************************************/
+/*                                                             */
+/*  MinutesPastMidnight                                        */
+/*                                                             */
+/*  Return the system time in minutes past midnight            */
+/*                                                             */
+/***************************************************************/
+int MinutesPastMidnight(int realtime)
+{
+    return (SystemTime(realtime) / 60);
+}
+
+
 /***************************************************************/
 /*                                                             */
 /*  SystemDate                                                 */
@@ -777,11 +784,11 @@ long SystemTime(int realtime)
 /***************************************************************/
 int SystemDate(int *y, int *m, int *d)
 {
-    time_t tloc;
+    time_t now;
     struct tm *t;
 
-    (void) time(&tloc);
-    t = localtime(&tloc);
+    now = time(NULL);
+    t = localtime(&now);
 
     *d = t->tm_mday;
     *m = t->tm_mon;
