@@ -5,7 +5,7 @@
 /*  Function Prototypes.                                       */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2023 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2024 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -22,6 +22,9 @@
 /* Characters to ignore */
 #define isempty(c) (isspace(c) || ((c) == '\\'))
 
+#define IsServerMode() (Daemon < 0)
+#define ShouldFork (!DontFork)
+
 #include "dynbuf.h"
 #include <ctype.h>
 
@@ -71,7 +74,8 @@ void OutputLine (FILE *fp);
 void CreateParser (char const *s, ParsePtr p);
 void DestroyParser (ParsePtr p);
 int PushToken (char const *tok, ParsePtr p);
-long SystemTime (int realtime);
+int SystemTime (int realtime);
+int MinutesPastMidnight (int realtime);
 int SystemDate (int *y, int *m, int *d);
 int DoIf (ParsePtr p);
 int DoElse (ParsePtr p);
@@ -170,6 +174,8 @@ int AddGlobalOmit(int dse);
 void set_lat_and_long_from_components(void);
 void set_components_from_lat_and_long(void);
 
+int GetTerminalBackground(void);
+
 char const *get_day_name(int wkday);
 char const *get_month_name(int mon);
 
@@ -178,6 +184,8 @@ void clear_callstack(void);
 int print_callstack(FILE *fp);
 void pop_call(void);
 void FixSpecialType(Trigger *trig);
+void WriteJSONTrigger(Trigger const *t, int include_tags, int today);
+void WriteJSONTimeTrigger(TimeTrig const *tt);
 #ifdef REM_USE_WCHAR
 #define _XOPEN_SOURCE 600
 #include <wctype.h>
