@@ -5,7 +5,7 @@
 /*  Routines for figuring out the trigger date of a reminder   */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2023 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2024 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -324,8 +324,11 @@ static int GetNextTriggerDate(Trigger *trig, int start, int *err, int *nextstart
 		break;
 	    }
 	    start--;
+            if (start < 0) {
+                break;
+            }
 	}
-	if (iter > MaxSatIter) {
+	if (start < 0 || iter > MaxSatIter) {
 	    /* omitfunc must have returned "true" too often */
 	    *err = E_CANT_TRIG;
 	    return -2;
@@ -388,6 +391,10 @@ static int GetNextTriggerDate(Trigger *trig, int start, int *err, int *nextstart
 		break;
 	    }
 	    simple--;
+            if (simple < 0) {
+                *err = E_CANT_TRIG;
+                return -2;
+            }
 	}
 	if (iter > MaxSatIter) {
 	    *err = E_CANT_TRIG;
